summaryrefslogtreecommitdiffstats
path: root/libkcal/resourcecached.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/resourcecached.cpp')
-rw-r--r--libkcal/resourcecached.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/libkcal/resourcecached.cpp b/libkcal/resourcecached.cpp
index a6365979..0e2d8d56 100644
--- a/libkcal/resourcecached.cpp
+++ b/libkcal/resourcecached.cpp
@@ -485,7 +485,7 @@ void ResourceCached::calendarIncidenceAdded( Incidence *i )
#endif
TQMap<Incidence *,bool>::ConstIterator it;
- it = mAddedIncidences.find( i );
+ it = mAddedIncidences.tqfind( i );
if ( it == mAddedIncidences.end() ) {
mAddedIncidences.insert( i, true );
}
@@ -501,7 +501,7 @@ void ResourceCached::calendarIncidenceChanged( Incidence *i )
#endif
TQMap<Incidence *,bool>::ConstIterator it;
- it = mChangedIncidences.find( i );
+ it = mChangedIncidences.tqfind( i );
// FIXME: If you modify an added incidence, there's no need to add it to mChangedIncidences!
if ( it == mChangedIncidences.end() ) {
mChangedIncidences.insert( i, true );
@@ -518,19 +518,19 @@ void ResourceCached::calendarIncidenceDeleted( Incidence *i )
#endif
if (i->hasRecurrenceID()) {
// This incidence has a parent; notify the parent of the child's death and do not destroy the parent!
// Get the parent
IncidenceList il = i->childIncidences();
IncidenceListIterator it;
it = il.begin();
- Incidence *parentIncidence;
- parentIncidence = this->incidence(*it);
+ Incidence *tqparentIncidence;
+ tqparentIncidence = this->incidence(*it);
// Remove the child
- calendarIncidenceChanged(parentIncidence);
+ calendarIncidenceChanged(tqparentIncidence);
}
else {
TQMap<Incidence *,bool>::ConstIterator it;
- it = mDeletedIncidences.find( i );
+ it = mDeletedIncidences.tqfind( i );
if ( it == mDeletedIncidences.end() ) {
mDeletedIncidences.insert( i, true );
}
@@ -518,19 +518,19 @@ void ResourceCached::calendarIncidenceDeleted( Incidence *i )
#endif
if (i->hasRecurrenceID()) {
- // This incidence has a parent; notify the parent of the child's death and do not destroy the parent!
- // Get the parent
+ // This incidence has a tqparent; notify the tqparent of the child's death and do not destroy the tqparent!
+ // Get the tqparent
IncidenceList il = i->childIncidences();
IncidenceListIterator it;